[00:39] *** alati joined
[00:41] <alati> greetings all.. hope all is well

[00:42] <alati> beginning a new journey to use raku for most of my tasks

[00:43] <alati> instead of googling and searching about I thought to come to the irc and ask if anyone might already have a project regarding gherkin/bdd and raku incorporation?

[00:44] <alati> I did come across raku++ for client side raku development. looks like a great project

[00:45] <alati> not that those 2 things are related but I'm just going across anything raku is currently involved with

[00:46] <[Coke]> you may want #raku instead of #raku-dev

[00:46] <alati> aha... Thanks Coke

[00:47] <alati> long ago I think my nick was myhrlin when we last chatted

[00:47] <alati> give or take 20 years or so

[02:45] *** alati left
[06:01] *** djinni`_ joined
[06:01] *** rnddim joined
[06:06] *** ShimmerFairy left
[06:06] *** rnddim is now known as ShimmerFairy

[06:08] *** djinni` left
[06:08] *** jjatria left
[06:14] *** jjatria joined
[06:15] *** kjp left
[06:19] *** kjp joined
[11:08] <Geth> ¦ rakudo/lizmat-69: ed3c29ba2a | (Elizabeth Mattijsen)++ | src/Raku/ast/expressions.rakumod

[11:08] <Geth> ¦ rakudo/lizmat-69: RakuAST: optimize ::Infix.IMPL-APPLY-SINK-TO-OPERANDS

[11:08] <Geth> ¦ rakudo/lizmat-69: 

[11:08] <Geth> ¦ rakudo/lizmat-69: In this relatively hot piece of code, replace for loops by native

[11:08] <Geth> ¦ rakudo/lizmat-69: nqp::while and use nqp::atpos instead of postcircumfix [].  For

[11:08] <Geth> ¦ rakudo/lizmat-69: reference, an nqp::while loop + nqp::atpos is about 2x as fast

[11:08] <Geth> ¦ rakudo/lizmat-69: as a for loop in nqp.  That's because the iterator overhead is

[11:08] <Geth> ¦ rakudo/lizmat-69: pretty big in nqp.  And using nqp ops also creates smaller bytecode

[11:08] <Geth> ¦ rakudo/lizmat-69: so more chance of inlining.

[11:08] <Geth> ¦ rakudo/lizmat-69: review: https://github.com/rakudo/rakudo/commit/ed3c29ba2a

[11:08] <Geth> ¦ rakudo: lizmat++ created pull request #6840: RakuAST: optimize ::Infix.IMPL-APPLY-SINK-TO-OPERANDS

[11:08] <Geth> ¦ rakudo: review: https://github.com/rakudo/rakudo/pull/6840

[11:16] *** finanalyst joined
[11:26] <Geth> ¦ rakudo/lizmat-70: e9c52759a4 | (Elizabeth Mattijsen)++ | src/Raku/ast/expressions.rakumod

[11:26] <Geth> ¦ rakudo/lizmat-70: RakuAST: optimize ::Assignment.IMPL-APPLY-SINK-TO-OPERANDS

[11:26] <Geth> ¦ rakudo/lizmat-70: 

[11:26] <Geth> ¦ rakudo/lizmat-70: In this relatively hot piece of code, replace for loops by native

[11:26] <Geth> ¦ rakudo/lizmat-70: nqp::while and use nqp::atpos instead of postcircumfix [].  For

[11:26] <Geth> ¦ rakudo/lizmat-70: reference, an nqp::while loop + nqp::atpos is about 2x as fast

[11:26] <Geth> ¦ rakudo/lizmat-70: as a for loop in nqp.  That's because the iterator overhead is

[11:26] <Geth> ¦ rakudo/lizmat-70: pretty big in nqp.  And using nqp ops also creates smaller bytecode

[11:26] <Geth> ¦ rakudo/lizmat-70: so more chance of inlining

[11:26] <Geth> ¦ rakudo/lizmat-70: review: https://github.com/rakudo/rakudo/commit/e9c52759a4

[11:27] <Geth> ¦ rakudo: lizmat++ created pull request #6841: RakuAST: optimize ::Assignment.IMPL-APPLY-SINK-TO-OPERANDS

[11:27] <Geth> ¦ rakudo: review: https://github.com/rakudo/rakudo/pull/6841

[12:41] <Geth> ¦ rakudo/lizmat-71: 1dc6a0f009 | (Elizabeth Mattijsen)++ | src/Raku/ast/resolver.rakumod

[12:41] <Geth> ¦ rakudo/lizmat-71: RakuAST: streamline ::Resolver::(EVAL|Compile)

[12:41] <Geth> ¦ rakudo/lizmat-71: 

[12:41] <Geth> ¦ rakudo/lizmat-71: Specifically the .current-scope and .outer.scope methods, as these

[12:41] <Geth> ¦ rakudo/lizmat-71: are pretty hot during compilation, and use atpos(..,i) vs ...[i]

[12:41] <Geth> ¦ rakudo/lizmat-71: is about 2x as fast.

[12:41] <Geth> ¦ rakudo/lizmat-71: review: https://github.com/rakudo/rakudo/commit/1dc6a0f009

[12:42] <Geth> ¦ rakudo: lizmat++ created pull request #6842: RakuAST: streamline ::Resolver::(EVAL|Compile)

[12:42] <Geth> ¦ rakudo: review: https://github.com/rakudo/rakudo/pull/6842

[13:17] <Geth> ¦ rakudo/lizmat-72: c3a9913652 | (Elizabeth Mattijsen)++ | src/Raku/ast/resolver.rakumod

[13:17] <Geth> ¦ rakudo/lizmat-72: RakuAST: streamline ::Resolver::(EVAL|Compile).find-scope-property

[13:17] <Geth> ¦ rakudo/lizmat-72: 

[13:17] <Geth> ¦ rakudo/lizmat-72: Another hot method during compilation, rewritten to use atpos

[13:17] <Geth> ¦ rakudo/lizmat-72: and no return statements.

[13:17] <Geth> ¦ rakudo/lizmat-72: review: https://github.com/rakudo/rakudo/commit/c3a9913652

[13:17] <Geth> ¦ rakudo: lizmat++ created pull request #6843: RakuAST: streamline ::Resolver::(EVAL|Compile).find-scope-property

[13:17] <Geth> ¦ rakudo: review: https://github.com/rakudo/rakudo/pull/6843

[14:40] <[Coke]> blin clear through 3388d045c2

[14:40] <linkable6> (2026-10-10) https://github.com/rakudo/rakudo/commit/3388d045c2 Bump NQP to fix an issue with spesh, ugexe++

[22:38] <lizmat> c: HEAD my @k[*;3]; dd @k[3]

[22:38] <committable6> lizmat, ¦HEAD(3388d04): «Array␤»

[23:19] *** finanalyst left
